from setuptools import setup

setup(name='sceepy',
      version='0.0',
      description='Gaussian and Binomial distributions',
      packages=['sceepy'],
      author_email='mihajlovic.aleksa@gmail.com',
      zip_safe=False)